@@ -53,12 +53,14 @@ void amitk_data_set_`'m4_Variable_Type`'_`'m4_Scale_Dim`'_`'m4_Intercept`'calc_f
 
   /* note, we can't cancel this */
   if (update_func != NULL) {
-    temp_string = g_strdup_printf(_("Calculating Max/Min Values for:\n   %s"), AMITK_OBJECT_NAME(data_set));
+    temp_string = g_strdup_printf(_("Calculating Max/Min Values for:\n   %s"), 
+				  AMITK_OBJECT_NAME(data_set) == NULL ? "dataset" :
+				  AMITK_OBJECT_NAME(data_set));
     (*update_func)(update_data, temp_string, (gdouble) 0.0);
     g_free(temp_string);
   }
   total_planes = AMITK_DATA_SET_TOTAL_PLANES(data_set);
-  divider = ((total_planes/AMIDE_UPDATE_DIVIDER) < 1) ? 1 : (total_planes/AMIDE_UPDATE_DIVIDER);
+  divider = ((total_planes/AMITK_UPDATE_DIVIDER) < 1) ? 1 : (total_planes/AMITK_UPDATE_DIVIDER);
 
   i = zero_voxel;
   i_plane=0;
@@ -73,7 +75,7 @@ void amitk_data_set_`'m4_Variable_Type`'_`'m4_Scale_Dim`'_`'m4_Intercept`'calc_f
       for (i.z = 0; i.z < dim.z; i.z++, i_plane++) {
 	if (update_func != NULL) {
 	  x = div(i_plane, divider);
-	  if (x.rem == 0)
+	  if (x.rem == 0) 
 	    (*update_func)(update_data, NULL, ((gdouble) i_plane)/((gdouble)total_planes));
 	}
 	for (i.y = 0; i.y < dim.y; i.y++) 
@@ -146,7 +148,7 @@ void amitk_data_set_`'m4_Variable_Type`'_`'m4_Scale_Dim`'_`'m4_Intercept`'calc_d
     g_free(temp_string);
   }
   total_planes = AMITK_DATA_SET_TOTAL_PLANES(data_set);
-  divider = ((total_planes/AMIDE_UPDATE_DIVIDER) < 1) ? 1 : (total_planes/AMIDE_UPDATE_DIVIDER);
+  divider = ((total_planes/AMITK_UPDATE_DIVIDER) < 1) ? 1 : (total_planes/AMITK_UPDATE_DIVIDER);
 
   /* now "bin" the data */
   j = zero_voxel;
